.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

SuperRAENN Documentation
========================

SuperRAENN is an open-source Python package for the photometric classification of supernovae in the following categories: Type I superluminos supernovae, Type II, Type IIn, Type Ia and Type Ib/c. It is described in detail in Villar et al. (in prep.). SuperRAENN is optimized for use with complete (rather than realtime) light curves from the Pan-STARRS Medium Deep Survey. Users will need to train the classifier on their own data for optimal results.

.. toctree::
   :maxdepth: 2

   installation
   usage
   api
   release-history